@@ -68,6 +68,18 @@ fn correctly_escape_external_arguments() {
     assert_eq!(actual.out, "$0");
 }
 
+#[test]
+fn execute_binary_in_string() {
+    let actual = nu!(
+    cwd: ".",
+    r#"
+        let cmd = echo
+        ^$"($cmd)" '$0'
+    "#);
+
+    assert_eq!(actual.out, "$0");
+}
+
 #[test]
 fn redirects_custom_command_external() {
     let actual = nu!(cwd: ".", r#"def foo [] { nu --testbin cococo foo bar }; foo | str length "#);
@@ -199,7 +211,8 @@ mod stdin_evaluation {
 
 mod external_words {
     use super::nu;
-
+    use nu_test_support::fs::Stub::FileWithContent;
+    use nu_test_support::{pipeline, playground::Playground};
     #[test]
     fn relaxed_external_words() {
         let actual = nu!(cwd: ".", r#"
@@ -217,6 +230,38 @@ mod external_words {
 
         assert_eq!(actual.out, "test \"things\"");
     }
+
+    #[rstest::rstest]
+    #[case("sample.toml", r#""sample.toml""#)]
+    #[case("a sample file.toml", r#""a sample file.toml""#)]
+    #[case("quote'mark.toml", r#""quote'mark.toml""#)]
+    #[cfg_attr(
+        not(target_os = "windows"),
+        case(r#"quote"mark.toml"#, r#"$"quote(char double_quote)mark.toml""#)
+    )]
+    #[cfg_attr(not(target_os = "windows"), case("?mark.toml", r#""?mark.toml""#))]
+    #[cfg_attr(not(target_os = "windows"), case("*.toml", r#""*.toml""#))]
+    #[cfg_attr(not(target_os = "windows"), case("*.toml", "*.toml"))]
+    #[case("$ sign.toml", r#""$ sign.toml""#)]
+    fn external_arg_with_special_characters(#[case] path: &str, #[case] nu_path_argument: &str) {
+        Playground::setup("external_arg_with_quotes", |dirs, sandbox| {
+            sandbox.with_files(vec![FileWithContent(
+                path,
+                r#"
+                    nu_party_venue = "zion"
+                "#,
+            )]);
+
+            let actual = nu!(
+                cwd: dirs.test(), pipeline(
+                &format!(r#"
+                    nu --testbin meow {} | from toml | get nu_party_venue
+                "#, nu_path_argument)
+            ));
+
+            assert_eq!(actual.out, "zion");
+        })
+    }
 }
 
 mod nu_commands {
@@ -311,4 +356,93 @@ mod external_command_arguments {
             },
         )
     }
+
+    #[test]
+    fn proper_subexpression_paths_in_external_args() {
+        Playground::setup(
+            "expands_table_of_primitives_to_positional_arguments",
+            |dirs, sandbox| {
+                sandbox.with_files(vec![
+                    EmptyFile("jonathan_likes_cake.txt"),
+                    EmptyFile("andres_likes_arepas.txt"),
+                    EmptyFile("ferris_not_here.txt"),
+                ]);
+
+                let actual = nu!(
+                cwd: dirs.test(), pipeline(
+                r#"
+                    nu --testbin cococo (ls | sort-by name | get name).1
+                "#
+                ));
+
+                assert_eq!(actual.out, "ferris_not_here.txt");
+            },
+        )
+    }
+
+    #[cfg(not(windows))]
+    #[test]
+    fn string_interpolation_with_an_external_command() {
+        Playground::setup(
+            "string_interpolation_with_an_external_command",
+            |dirs, sandbox| {
+                sandbox.mkdir("cd");
+
+                sandbox.with_files(vec![EmptyFile("cd/jonathan_likes_cake.txt")]);
+
+                let actual = nu!(
+                cwd: dirs.test(), pipeline(
+                r#"
+                    ^ls $"(pwd)/cd"
+                "#
+                ));
+
+                assert_eq!(actual.out, "jonathan_likes_cake.txt");
+            },
+        )
+    }
+
+    #[cfg(not(windows))]
+    #[test]
+    fn semicolons_are_sanitized_before_passing_to_subshell() {
+        let actual = nu!(
+            cwd: ".",
+            "^echo \"a;b\""
+        );
+
+        assert_eq!(actual.out, "a;b");
+    }
+
+    #[cfg(not(windows))]
+    #[test]
+    fn ampersands_are_sanitized_before_passing_to_subshell() {
+        let actual = nu!(
+            cwd: ".",
+            "^echo \"a&b\""
+        );
+
+        assert_eq!(actual.out, "a&b");
+    }
+
+    #[cfg(not(windows))]
+    #[test]
+    fn subcommands_are_sanitized_before_passing_to_subshell() {
+        let actual = nu!(
+            cwd: ",",
+            "^echo \"$(ls)\""
+        );
+
+        assert_eq!(actual.out, "$(ls)");
+    }
+
+    #[cfg(not(windows))]
+    #[test]
+    fn shell_arguments_are_sanitized_even_if_coming_from_other_commands() {
+        let actual = nu!(
+            cwd: ",",
+            "^echo (echo \"a;&$(hello)\")"
+        );
+
+        assert_eq!(actual.out, "a;&$(hello)");
+    }
 }
